@@ -62,47 +62,47 @@ class BaseView(View):
         else:
             return HttpResponse(status=204)
 
-    def get(self, request, filters, initkwargs):
+    def get(self, request, filters):
         raise NotImplemented('GET not Allowed!')
 
-    def post(self, request, filters, initkwargs, **kwargs):
+    def post(self, request, filters, **kwargs):
         raise NotImplemented('POST not Allowed!')
 
-    def put(self, request, filters, initkwargs, **kwargs):
+    def put(self, request, filters, **kwargs):
         raise NotImplemented('PUT not Allowed!')
 
-    def delete(self, request, filters, initkwargs):
+    def delete(self, request, filters, **kwargs):
         raise NotImplemented('DELETE not Allowed!')
 
 
 class BaseCrudView(BaseView):
 
-    def get(self, request, filters, initkwargs):
-        crud = self.schema_class(filters, **initkwargs)
+    def get(self, request, filters, **kwargs):
+        crud = self.schema_class(filters, **kwargs.pop('initkwargs', {}))
         self.data = crud.get()
         return self._respond()
 
-    def post(self, request, filters, initkwargs, **kwargs):
+    def post(self, request, filters, **kwargs):
         print('in post')
-        crud = self.schema_class(filters, **initkwargs)
+        crud = self.schema_class(filters, **kwargs.pop('initkwargs', {}))
         body = unjsonize(request.body.decode())
         self.data = crud.post(**body, **kwargs)
         return self._respond()
 
-    def bulk_post(self, request, filters, initkwargs, **kwargs):
-        crud = self.schema_class(filters, **initkwargs)
+    def bulk_post(self, request, filters, **kwargs):
+        crud = self.schema_class(filters, **kwargs.pop('initkwargs', {}))
         body = unjsonize(request.body.decode())
         self.data = crud.bulk_post(data=body, **filters, **kwargs)
         return self._respond()
 
-    def put(self, request, filters, initkwargs, **kwargs):
-        crud = self.schema_class(filters, **initkwargs)
+    def put(self, request, filters, **kwargs):
+        crud = self.schema_class(filters, **kwargs.pop('initkwargs', {}))
         body = unjsonize(request.body.decode())
         self.data = crud.put(**body, **kwargs)
         return self._respond()
 
-    def delete(self, request, filters, initkwargs):
-        crud = self.schema_class(filters, **initkwargs)
+    def delete(self, request, filters, **kwargs):
+        crud = self.schema_class(filters, **kwargs.pop('initkwargs', {}))
         if not crud.delete():
             return HttpResponse(status=404)
         return self._respond()
